@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2014 Fanficdownloader team, 2015 FanFicFare team
+# Copyright 2014 Fanficdownloader team, 2018 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,18 +16,21 @@
 #
 
 # Software: eFiction
-# import time
-# import urllib
+from __future__ import absolute_import
+
 import logging
 logger = logging.getLogger(__name__)
 import re
-import urllib2
 
 import bs4 as bs
 from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
 
-from base_adapter import BaseSiteAdapter, makeDate
+# py2 vs py3 transition
+from ..six import text_type as unicode
+from ..six.moves.urllib.error import HTTPError
+
+from .base_adapter import BaseSiteAdapter, makeDate
 
 """
 This is a generic adapter for eFiction based archives (see
@@ -62,7 +65,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
     def __init__(self, config, url):
         BaseSiteAdapter.__init__(self, config, url)
         self.story.setMetadata('siteabbrev',self.getSiteAbbrev())
-        self.decode = self.getEncoding()
+        self.set_decode(self.getEncoding())
         storyId = re.compile(self.getSiteURLPattern()).match(self.url).group('storyId')
         self.story.setMetadata('storyId', storyId)
         self._setURL(self.getViewStoryUrl(storyId))
@@ -74,7 +77,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
     def getConfigSections(cls):
         "Only needs to be overriden if has additional ini sections."
         return ['base_efiction',cls.getConfigSection()]
-    
+
     @classmethod
     def getAcceptDomains(cls):
         return [cls.getSiteDomain(),'www.' + cls.getSiteDomain()]
@@ -87,6 +90,10 @@ class BaseEfictionAdapter(BaseSiteAdapter):
     def getSiteURLPattern(self):
         return r"https?://(www\.)?%s%s/%s\?sid=(?P<storyId>\d+)" % (self.getSiteDomain(), self.getPathToArchive(), self.getViewStoryPhpName())
 
+    @classmethod
+    def getSiteURLFragment(self):
+        return self.getSiteDomain()+self.getPathToArchive()
+
     @classmethod
     def getEncoding(cls):
         """
@@ -132,9 +139,16 @@ class BaseEfictionAdapter(BaseSiteAdapter):
         """
         return "%d %b %Y"
 
+    @classmethod
+    def getProtocol(self):
+        """
+        Some, but not all site now require https.
+        """
+        return "http"
+
     @classmethod
     def getUrlForPhp(self, php):
-        return "http://%s%s/%s" % (self.getSiteDomain(), self.getPathToArchive(), php)
+        return "%s://%s%s/%s" % (self.getProtocol(),self.getSiteDomain(), self.getPathToArchive(), php)
 
     @classmethod
     def getViewStoryUrl(self, storyId):
@@ -205,7 +219,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
         """
         try:
             html = self._fetchUrl(url)
-        except urllib2.HTTPError, e:
+        except HTTPError as e:
             if e.code == 404:
                 raise exceptions.StoryDoesNotExist(self.url)
             else:
@@ -229,7 +243,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
             # TODO handle '../../' and so on
             if img['src'].startswith('/'):
                 img['src'] = img['src'][1:]
-            img['src'] = "http://%s%s/%s" % (self.getSiteDomain(), self.getPathToArchive(), img['src'])
+            img['src'] = "%s://%s%s/%s" % (self.getProtocol(),self.getSiteDomain(), self.getPathToArchive(), img['src'])
 
         return soup
 
@@ -256,6 +270,26 @@ class BaseEfictionAdapter(BaseSiteAdapter):
         else:
             return True
 
+    def handleMetadataPairHTML(self, key, valueHTML):
+        """
+        Handles a key-value pair of story metadata.
+
+        Returns straight away if the value is 'None' (that's a string)
+
+        Allows for handling of HTML values before calling
+        handleMetadataPair() to handle string values.
+        """
+        if valueHTML == 'None':
+            return
+        elif key == 'Summary':
+            ## will be de-HTML'd inside setDescription if keep_summary_html:false
+            self.setDescription(self.url, valueHTML)
+        else:
+            ## strip trailing line breaks
+            valueStr = re.sub("<br/>", "", valueHTML)
+            valueStr = stripHTML(valueStr)
+            self.handleMetadataPair(key,valueStr)
+
     def handleMetadataPair(self, key, value):
         """
         Handles a key-value pair of story metadata.
@@ -271,8 +305,6 @@ class BaseEfictionAdapter(BaseSiteAdapter):
         """
         if value == 'None':
             return
-        elif key == 'Summary':
-            self.setDescription(self.url, value)
         elif 'Genre' in key:
             for val in re.split("\s*,\s*", value):
                 self.story.addToList('genre', val)
@@ -311,7 +343,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
             for val in re.split("\s*,\s*", value):
                 self.story.addToList('ships', val)
         elif key == 'Series':
-            ## TODO is not a link in the printable view, so no seriesURL possible 
+            ## TODO is not a link in the printable view, so no seriesURL possible
             self.story.setMetadata('series', value)
         else:
             # Any other metadata found, convert label to lower case
@@ -369,7 +401,7 @@ class BaseEfictionAdapter(BaseSiteAdapter):
         # title and author
         pagetitleDiv = soup.find("div", {"id": "pagetitle"})
         if pagetitleDiv.find('a') is None:
-            raise execeptions.FailedToDownload("Couldn't find title and author")
+            raise exceptions.FailedToDownload("Couldn't find title and author")
         self.story.setMetadata('title', pagetitleDiv.find("a").string)
         authorLink = pagetitleDiv.findAll("a")[1]
         self.story.setMetadata('author', authorLink.string)
@@ -394,19 +426,20 @@ class BaseEfictionAdapter(BaseSiteAdapter):
                 nextEl = nextEl.nextSibling
             key = labelSpan.string.strip()
 
-            ## strip trailing line breaks
-            valueStr = re.sub("<br/>", "", valueStr)
-
             ## strip trailing colons
             key = re.sub("\s*:\s*$", "", key)
 
             ## strip whitespace
             key = key.strip()
-            valueStr = stripHTML(valueStr)
 
-            self.handleMetadataPair(key, valueStr)
+            self.handleMetadataPairHTML(key, valueStr)
 
-        ## Chapter URLs 
+        ## Retrieving the story notes
+        sn = soup.find('div', {'class':'noteinfo'})
+        if sn:
+            self.story.setMetadata('storynotes', stripHTML(sn))
+
+        ## Chapter URLs
 
         # If we didn't bulk-load the whole chapter we now need to load
         # the non-printable HTML version of the landing page (i.e. the story
@@ -421,7 +454,8 @@ class BaseEfictionAdapter(BaseSiteAdapter):
                 chapterId = m.group('chapterId')
                 chapterLink = b.findNext("a")
                 chapterLink['href'] = "%s&chapter=%s" % (self.url, chapterId)
-                self.chapterUrls.append((chapterLink.string, chapterLink['href']))
+                if chapterLink.string !='Back to index':
+                    self.add_chapter(chapterLink.string, chapterLink['href'])
 
         ## Store reference to soup for getChapterText
         self.html = soup
