@@ -333,9 +333,12 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                 kwords = atag.next_sibling.strip()
         return words,kwords
 
-    def fetch_threadmarks(self,url,tmcat_name,tmcat_num, passed_tmcat_index=0):
-        logger.debug("fetch_threadmarks(%s,tmcat_num=%s,passed_tmcat_index:%s,url=%s)"%(tmcat_name,tmcat_num, passed_tmcat_index, url))
+    def fetch_threadmarks(self,url,tmcat_name,tmcat_num, passed_tmcat_index=0, dedup=[]):
         threadmarks=[]
+        if url in dedup:
+            logger.debug("fetch_threadmarks(%s,tmcat_num=%s,passed_tmcat_index:%s,url=%s,dedup=%s)\nDuplicate threadmark URL, skipping"%(tmcat_name,tmcat_num, passed_tmcat_index, url, dedup))
+            return threadmarks
+        dedup = dedup + [url]
         soupmarks = self.make_soup(self._fetchUrl(url))
         tm_list = self.get_threadmarks_list(soupmarks)
         if not tm_list: # load-range don't match
@@ -350,7 +353,8 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                 threadmarks.extend(self.fetch_threadmarks(self.get_threadmark_range_url(tm_item,tmcat_num),
                                                           tmcat_name,
                                                           tmcat_num,
-                                                          tmcat_index))
+                                                          tmcat_index,
+                                                          dedup))
                 tmcat_index = len(threadmarks)
                 after=True
             else:
@@ -500,10 +504,10 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         # otherwise, use first post links--include first post since
         # that's often also the first chapter.
 
-        if self.num_chapters() < 1:
+        if self.num_chapters() < 1 or self.getConfig('always_include_first_post_chapters',False):
             self.add_chapter(first_post_title,useurl)
             # logger.debug(index_post)
-            for (url,name,tag) in [ (x['href'],stripHTML(x),x) for x in index_post.find_all('a') ]:
+            for (url,name,tag) in [ (x['href'],stripHTML(x),x) for x in index_post.find_all('a',href=True) ]:
                 (is_chapter_url,url) = self._is_normalize_chapterurl(url)
                 # skip quote links as indicated by up arrow character or data-xf-click=attribution
                 if is_chapter_url and name != u"\u2191" and tag.get("data-xf-click",None)!="attribution":
@@ -549,12 +553,12 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         return topsoup.find('li',{'class':'message'}) # limit first post for date stuff below. ('#' posts above)
 
     def get_first_post_body(self,topsoup):
-        bq = self.get_first_post(topsoup).find('blockquote')
+        bq = self.get_first_post(topsoup).find('blockquote',{'class':'messageText'})
         bq.name='div'
         return bq
 
     def get_post_body(self,souptag):
-        bq = souptag.find('blockquote')
+        bq = souptag.find('blockquote',{'class':'messageText'})
         if not bq:
             bq = souptag.find('div',{'class':'messageText'}) # cached gets if it was already used before
         bq.name='div'
@@ -582,7 +586,7 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             datestr = re.sub(r' (\d[^\d])',r' 0\1',datestr) # add leading 0 for single digit day & hours.
             return makeDate(datestr, self.dateformat)
         except:
-            logger.debug('No date found in %s'%parenttag,exc_info=True)
+            logger.debug('No date found in %s, going on without'%parenttag,exc_info=True)
             return None
 
     def cache_posts(self,topsoup):
@@ -625,7 +629,7 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             for offset in range(0,3):
                 souptag = self.get_cache_post(url)
 
-                if not souptag:
+                if not souptag and url in self.threadmarks_for_reader:
                     (tmcat_num,tmcat_index)=self.threadmarks_for_reader[url]
                     reader_page_num = int((tmcat_index+posts_per_page)/posts_per_page) + offset
                     logger.debug('Reader page offset:%s tmcat_num:%s tmcat_index:%s'%(offset,tmcat_num,tmcat_index))
