@@ -278,6 +278,7 @@ def get_valid_set_options():
                'apocrypha_to_omake':(base_xenforo_list,None,boollist),
                'replace_failed_smilies_with_alt_text':(base_xenforo_list,None,boollist),
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
+               'always_include_first_post_chapters':(base_xenforo_list,None,boollist),
                'fix_pseudo_html': (['webnovel.com'], None, boollist),
                'fix_excess_space': (['novelonlinefull.com', 'novelall.com'], ['epub', 'html'], boollist)
                }
@@ -486,6 +487,7 @@ def get_valid_keywords():
                  'internalize_text_links',
                  'replace_failed_smilies_with_alt_text',
                  'use_threadmark_wordcounts',
+                 'always_include_first_post_chapters',
                  'datethreadmark_format',
                  'fix_pseudo_html',
                  'fix_excess_space',
@@ -1056,10 +1058,10 @@ class Configuration(configparser.SafeConfigParser):
         if 'Accept' not in headers:
             headers['Accept']="text/html,*/*"
 
-        # if "xf2test" in url:
-        #     import base64
-        #     base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
-        #     headers['Authorization']=b"Basic %s" % base64string
+        if "xf2test" in url:
+            import base64
+            base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
+            headers['Authorization']=b"Basic %s" % base64string
 
         req = Request(url,
                       data=ensure_binary(urlencode(parameters)),
@@ -1129,10 +1131,10 @@ class Configuration(configparser.SafeConfigParser):
             ## not present at all
             headers.append(('Referer',referer))
 
-        # if "xf2test" in url:
-        #     import base64
-        #     base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
-        #     headers.append(('Authorization', b"Basic %s" % base64string))
+        if "xf2test" in url:
+            import base64
+            base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
+            headers.append(('Authorization', b"Basic %s" % base64string))
 
         self.opener.addheaders = headers
 
